# cimport

a Foreign language Import library for python

## Instalation

through pip stable:
```bash
pip install cimport
```

directly from github:
```bash
pip install get+https://github.com/Fakesum/cimport
```

## TODO

- [ ] Docs
- [ ] examples
- [x] Tests
- [ ] Type-hinting